@@ -2,7 +2,7 @@ using System;
 using System.Collections;
 
 namespace FSpot {
-	public class TimeAdaptor : GroupAdaptor {
+	public class TimeAdaptor : GroupAdaptor, FSpot.ILimitable {
 		public PhotoQuery query;
 
 		private int span;
@@ -16,16 +16,21 @@ namespace FSpot {
 		public override void SetGlass (int min)
 		{
 			DateTime date = DateFromIndex (min);
+			
+			if (GlassSet != null)
+				GlassSet (this, LookupItem (date));
+		}
 
+		public int LookupItem (System.DateTime date)
+		{
 			int i = 0;
 			while (i < query.Photos.Length && query.Photos [i].Time < date)
 				i++;
-			
-			if (GlassSet != null)
-				GlassSet (this, i);
+
+			return i;
 		}
 
-		public override void SetLimits (int min, int max) 
+		public void SetLimits (int min, int max) 
 		{
 			Console.WriteLine ("min {0} max {1}", min, max);
 			DateTime start = DateFromIndex (min);
@@ -63,7 +68,7 @@ namespace FSpot {
 
 			return data.Months[item % 12];
 		}
-		
+
 		public DateTime DateFromIndex (int item) 
 		{
 			item = Math.Max (item, 0);
@@ -74,8 +79,16 @@ namespace FSpot {
 			
 			return new DateTime (year, month, 1);
 		}
+
+		private void HandleChanged (IBrowsableCollection sender)
+		{
+			Console.WriteLine ("Reloading");
+			Reload ();
+		}
 		
-		public void Load () {
+		public override event ChangedHandler Changed;
+		public override void Reload () 
+		{
 			years.Clear ();
 
 			Photo [] photos = query.Store.Query (null, null);
@@ -91,7 +104,7 @@ namespace FSpot {
 						data.Year = current;
 						data.Months = new int [12];
 						years.Add (data);
-						Console.WriteLine ("Found Year {0}", current);
+						//Console.WriteLine ("Found Year {0}", current);
 					}
 					data.Months [photo.Time.Month - 1] += 1;
 				}
@@ -101,13 +114,17 @@ namespace FSpot {
 				data.Months = new int [12];
 				years.Add (data);
 			}
+
+ 			if (Changed != null)
+				Changed (this);
 		}
 
 
 		public TimeAdaptor (PhotoQuery query) {
 			this.query = query;
+			this.query.Changed += HandleChanged;
 			
-			Load ();
+			Reload ();
 		}
 	}
 }
